API reference
=============

.. automodule:: hpvsim
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   hpvsim.data

Submodules
----------

.. toctree::
   :maxdepth: 4

   hpvsim.analysis
   hpvsim.base
   hpvsim.calibration
   hpvsim.defaults
   hpvsim.immunity
   hpvsim.interventions
   hpvsim.misc
   hpvsim.parameters
   hpvsim.people
   hpvsim.plotting
   hpvsim.population
   hpvsim.run
   hpvsim.settings
   hpvsim.sim
   hpvsim.utils
   hpvsim.version
